<?php

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;


class Payplantation extends PaymentModule
{
    public function __construct()
    {
        $this->name = 'payplantation';
        $this->author = 'KhalilFarah';
        $this->version = '1.0.0';
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('PayPlantation');
        $this->description = $this->l('Pay with CreditCard or PayPlantation Wallet.');
        $this->ps_versions_compliancy = ['min' => '1.7.0.0', 'max' => '1.7.99.999'];
    }

    public function install()
    {
        return parent::install()
        && $this->registerHook('displayPaymentReturn')
        && $this->registerHook('paymentOptions');
    }

    public function uninstall()
    {
        return parent::uninstall();
    }

    private function _postValidation()
    {
        if (Tools::isSubmit('btnSubmit')) {
            if (!Tools::getValue('plantation_id')) {
                $this->_postErrors[] = $this->l('The "Client Id" field is required.');
            } elseif (!Tools::getValue('plantation_secret')) {
                $this->_postErrors[] = $this->l('The "Secret Key" field is required.');
            }
        }
    }

    private function _postProcess()
    {
        if (Tools::isSubmit('btnSubmit')) {
            Configuration::updateValue('plantation_id', Tools::getValue('plantation_id'));
            Configuration::updateValue('plantation_secret', Tools::getValue('plantation_secret'));
            Configuration::updateValue('plantation_desc', Tools::getValue('plantation_desc'));
        }

        $this->_html .= $this->displayConfirmation($this->l('Settings updated'));
    }

    public function getContent()
    {
        $logo = Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/views/img/white_logo.png');
        $this->_html = '';
        $this->_html .= '
            <div class="alert alert-info">
                 <p><img src="'.$logo.'" width="150px">
                     <strong>'.$this->l('Have your customers pay with PayPlantation via CreditCard or PayPlantation Wallet.').'</strong>
                 </p>
            </div>';
        if (Tools::isSubmit('btnSubmit')) {
            $this->_postValidation();
            if (!count($this->_postErrors)) {
                $this->_postProcess();
            } else {
                foreach ($this->_postErrors as $err) {
                    $this->_html .= $this->displayError($err);
                }
            }
        }


        $this->_html .= $this->renderForm();

        return $this->_html;
    }

    public function renderForm()
    {
        $fields_form = [
              'form' => [
                  'legend' => [
                      'title' => $this->l('Contact details'),
                      'icon' => 'icon-envelope',
                  ],
                  'input' => [
                      [
                          'type' => 'text',
                          'label' => $this->l('Set Client Id'),
                          'desc' => $this->l('Client Id , Provided by PayPlantation'),
                          'name' => 'plantation_id',
                          'required' => true,
                      ],
                      [
                          'type' => 'text',
                          'label' => $this->l('Set Secret Key'),
                          'desc' => $this->l('Secret Key, Provided by PayPlantation'),
                          'name' => 'plantation_secret',
                          'required' => true,
                      ],
                      [
                          'type' => 'textarea',
                          'label' => $this->l('Payment Description'),
                          'desc' => $this->l('Description to display for the customer.'),
                          'name' => 'plantation_desc',
                          'required' => false,
                      ]
                  ],
                  'submit' => [
                      'title' => $this->l('Save'),
                  ],
              ],
          ];

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->id = (int) Tools::getValue('id_carrier');
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'btnSubmit';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = [
              'fields_value' => $this->getConfigFieldsValues(),
          ];

        return $helper->generateForm([$fields_form]);
    }


    public function getConfigFieldsValues()
    {
        $config_fields = [
                  'plantation_id' => Tools::getValue('plantation_id', Configuration::get('plantation_id')),
                  'plantation_secret' => Tools::getValue('plantation_secret', Configuration::get('plantation_secret')),
                  'plantation_desc' => Tools::getValue('plantation_desc', Configuration::get('plantation_desc')),
                ];

        return $config_fields;
    }

    public function HookDisplayPaymentReturn()
    {
        $this->context->smarty->assign([]);

        return $this->display(__FILE__, 'views/templates/hook/return.tpl');
    }

    public function HookPaymentOptions($params)
    {

  
        $description = Tools::getValue('plantation_desc', Configuration::get('plantation_desc'));

        if ('' != $description) {
            $this->description = $description;
        }

        $logo = Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/views/img/white_logo.png');
        $info = '
         <h5>
            <img class="card-img-top" src="'.$logo.'" width="100px">
             '.$this->description.' 
         </h5>';
        $link = $this->context->link->getModuleLink($this->name, 'payment', ['action' => 'redirect'], true);
        $payplantation = new PaymentOption();
        $payplantation->setModuleName($this->name)
            ->setCallToActionText($this->displayName)
            ->setAdditionalInformation($info)
            ->setAction($link);
        return [$payplantation];
    }
}
